@@ -3,7 +3,38 @@ import pytest
 from decimal import Decimal
 from contextlib import contextmanager
 
-import fpdf
+from fpdf.drawing import (
+    Arc,
+    BezierCurve,
+    Close,
+    Ellipse,
+    HorizontalLine,
+    ImplicitClose,
+    Line,
+    Move,
+    PaintedPath,
+    QuadraticBezierCurve,
+    Rectangle,
+    RelativeArc,
+    RelativeBezierCurve,
+    RelativeHorizontalLine,
+    RelativeLine,
+    RelativeMove,
+    RelativeQuadraticBezierCurve,
+    RelativeVerticalLine,
+    RoundedRectangle,
+    VerticalLine,
+)
+from fpdf.drawing_primitives import Point, Transform, rgb8
+from fpdf.enums import (
+    BlendMode,
+    ClippingPathIntersectionRule,
+    IntersectionRule,
+    PathPaintRule,
+    StrokeCapStyle,
+    StrokeJoinStyle,
+)
+from fpdf.syntax import Name, Raw
 
 
 @contextmanager
@@ -19,21 +50,13 @@ def exception(exc):
 
 
 hex_colors = (
-    pytest.param(
-        "#CAB", fpdf.drawing.rgb8(r=0xCC, g=0xAA, b=0xBB, a=None), id="RGB hex 3"
-    ),
-    pytest.param(
-        "#FADE", fpdf.drawing.rgb8(r=0xFF, g=0xAA, b=0xDD, a=0xEE), id="RGBA hex 4"
-    ),
-    pytest.param(
-        "#C0FFEE", fpdf.drawing.rgb8(r=0xC0, g=0xFF, b=0xEE, a=None), id="RGB hex 6"
-    ),
-    pytest.param(
-        "#0D06F00D", fpdf.drawing.rgb8(r=0x0D, g=0x06, b=0xF0, a=0x0D), id="RGBA hex 8"
-    ),
+    pytest.param("#CAB", rgb8(r=0xCC, g=0xAA, b=0xBB, a=None), id="RGB hex 3"),
+    pytest.param("#FADE", rgb8(r=0xFF, g=0xAA, b=0xDD, a=0xEE), id="RGBA hex 4"),
+    pytest.param("#C0FFEE", rgb8(r=0xC0, g=0xFF, b=0xEE, a=None), id="RGB hex 6"),
+    pytest.param("#0D06F00D", rgb8(r=0x0D, g=0x06, b=0xF0, a=0x0D), id="RGBA hex 8"),
     pytest.param(
         "#0d06f00d",
-        fpdf.drawing.rgb8(r=0x0D, g=0x06, b=0xF0, a=0x0D),
+        rgb8(r=0x0D, g=0x06, b=0xF0, a=0x0D),
         id="RGBA hex 9, case insensitive",
     ),
     pytest.param("#asd", ValueError, id="bad characters"),
@@ -44,15 +67,11 @@ hex_colors = (
 )
 
 rgb_colors = (
-    pytest.param(
-        "rgb(204, 170, 187)", fpdf.drawing.rgb8(r=204, g=170, b=187, a=None), id="RGB"
-    ),
-    pytest.param(
-        "rgb(13, 6, 240, 5)", fpdf.drawing.rgb8(r=13, g=6, b=240, a=5), id="RGBA"
-    ),
+    pytest.param("rgb(204, 170, 187)", rgb8(r=204, g=170, b=187, a=None), id="RGB"),
+    pytest.param("rgb(13, 6, 240, 5)", rgb8(r=13, g=6, b=240, a=5), id="RGBA"),
     pytest.param(
         "rgb( 192,  255 ,  238 )",
-        fpdf.drawing.rgb8(r=192, g=255, b=238, a=None),
+        rgb8(r=192, g=255, b=238, a=None),
         id="rgb with extra spaces",
     ),
     pytest.param("rgb(a, s, d)", ValueError, id="bad characters"),
@@ -73,7 +92,7 @@ numbers = (
     pytest.param(-0.00004, "-0", id="negative zero"),
 )
 
-r = fpdf.drawing.Raw
+r = Raw
 
 
 class CustomPrimitive:
@@ -83,12 +102,10 @@ class CustomPrimitive:
 
 
 pdf_primitives = (
-    pytest.param(fpdf.drawing.Raw("raw output"), r("raw output"), id="raw"),
+    pytest.param(Raw("raw output"), r("raw output"), id="raw"),
     pytest.param(CustomPrimitive(), r("custom primitive"), id="custom"),
-    pytest.param(fpdf.drawing.Name("pdf_name"), r("/pdf_name"), id="name"),
-    pytest.param(
-        fpdf.drawing.Name("pdf#<name>"), r("/pdf#23#3Cname#3E"), id="escape name"
-    ),
+    pytest.param(Name("pdf_name"), r("/pdf_name"), id="name"),
+    pytest.param(Name("pdf#<name>"), r("/pdf#23#3Cname#3E"), id="escape name"),
     pytest.param("string", r("(string)"), id="string"),
     pytest.param("\r()\\", r(r"""(\r\(\)\\)"""), id="escape string"),
     pytest.param(b"bytes", r("<6279746573>"), id="bytes"),
@@ -98,14 +115,10 @@ pdf_primitives = (
     pytest.param(True, r("true"), id="True"),
     pytest.param(False, r("false"), id="False"),
     pytest.param(None, r("null"), id="None"),
+    pytest.param(["a", b"b", 0xC, Name("d")], r("[(a) <62> 12 /d]"), id="list"),
+    pytest.param(("a", b"b", 0xC, Name("d")), r("[(a) <62> 12 /d]"), id="tuple"),
     pytest.param(
-        ["a", b"b", 0xC, fpdf.drawing.Name("d")], r("[(a) <62> 12 /d]"), id="list"
-    ),
-    pytest.param(
-        ("a", b"b", 0xC, fpdf.drawing.Name("d")), r("[(a) <62> 12 /d]"), id="tuple"
-    ),
-    pytest.param(
-        {fpdf.drawing.Name("key"): "value", fpdf.drawing.Name("k2"): True},
+        {Name("key"): "value", Name("k2"): True},
         r("<< /key (value)\n/k2 true >>"),
         id="dict",
     ),
@@ -117,8 +130,8 @@ pdf_bad_primitives = (
     pytest.param({"key": "value", "k2": True}, ValueError, id="dict with bad keys"),
 )
 
-T = fpdf.drawing.Transform
-P = fpdf.drawing.Point
+T = Transform
+P = Point
 
 transforms = (
     pytest.param(T.identity(), P(1, 1), P(1, 1), id="identity"),
@@ -132,268 +145,268 @@ transforms = (
 
 coercive_enums = (
     pytest.param(
-        fpdf.drawing.IntersectionRule,
-        (fpdf.drawing.IntersectionRule.NONZERO, "NONZERO", "nonzero", "NONzero"),
-        fpdf.drawing.IntersectionRule.NONZERO,
+        IntersectionRule,
+        (IntersectionRule.NONZERO, "NONZERO", "nonzero", "NONzero"),
+        IntersectionRule.NONZERO,
         no_exception,
         id="IntersectionRule.NONZERO",
     ),
     pytest.param(
-        fpdf.drawing.IntersectionRule,
-        (fpdf.drawing.IntersectionRule.EVENODD, "EVENODD", "evenodd", "EveNOdD"),
-        fpdf.drawing.IntersectionRule.EVENODD,
+        IntersectionRule,
+        (IntersectionRule.EVENODD, "EVENODD", "evenodd", "EveNOdD"),
+        IntersectionRule.EVENODD,
         no_exception,
         id="IntersectionRule.EVENODD",
     ),
     pytest.param(
-        fpdf.drawing.IntersectionRule,
+        IntersectionRule,
         ("nonsense",),
         None,
         exception(ValueError),
         id="coerce bad string",
     ),
     pytest.param(
-        fpdf.drawing.IntersectionRule,
+        IntersectionRule,
         (1234,),
         None,
         exception(TypeError),
         id="coerce wrong type entirely",
     ),
     pytest.param(
-        fpdf.drawing.PathPaintRule,
-        (fpdf.drawing.PathPaintRule.STROKE, "stroke", "S"),
-        fpdf.drawing.PathPaintRule.STROKE,
+        PathPaintRule,
+        (PathPaintRule.STROKE, "stroke", "S"),
+        PathPaintRule.STROKE,
         no_exception,
         id="PathPaintRule.STROKE",
     ),
     pytest.param(
-        fpdf.drawing.PathPaintRule,
-        (fpdf.drawing.PathPaintRule.FILL_NONZERO, "fill_nonzero", "f"),
-        fpdf.drawing.PathPaintRule.FILL_NONZERO,
+        PathPaintRule,
+        (PathPaintRule.FILL_NONZERO, "fill_nonzero", "f"),
+        PathPaintRule.FILL_NONZERO,
         no_exception,
         id="PathPaintRule.FILL_NONZERO",
     ),
     pytest.param(
-        fpdf.drawing.PathPaintRule,
-        (fpdf.drawing.PathPaintRule.FILL_EVENODD, "fill_evenodd", "f*"),
-        fpdf.drawing.PathPaintRule.FILL_EVENODD,
+        PathPaintRule,
+        (PathPaintRule.FILL_EVENODD, "fill_evenodd", "f*"),
+        PathPaintRule.FILL_EVENODD,
         no_exception,
         id="PathPaintRule.FILL_EVENODD",
     ),
     pytest.param(
-        fpdf.drawing.PathPaintRule,
-        (fpdf.drawing.PathPaintRule.STROKE_FILL_NONZERO, "stroke_fill_nonzero", "B"),
-        fpdf.drawing.PathPaintRule.STROKE_FILL_NONZERO,
+        PathPaintRule,
+        (PathPaintRule.STROKE_FILL_NONZERO, "stroke_fill_nonzero", "B"),
+        PathPaintRule.STROKE_FILL_NONZERO,
         no_exception,
         id="PathPaintRule.STROKE_FILL_NONZERO",
     ),
     pytest.param(
-        fpdf.drawing.PathPaintRule,
-        (fpdf.drawing.PathPaintRule.STROKE_FILL_EVENODD, "stroke_fill_evenodd", "B*"),
-        fpdf.drawing.PathPaintRule.STROKE_FILL_EVENODD,
+        PathPaintRule,
+        (PathPaintRule.STROKE_FILL_EVENODD, "stroke_fill_evenodd", "B*"),
+        PathPaintRule.STROKE_FILL_EVENODD,
         no_exception,
         id="PathPaintRule.STROKE_FILL_EVENODD",
     ),
     pytest.param(
-        fpdf.drawing.PathPaintRule,
-        (fpdf.drawing.PathPaintRule.DONT_PAINT, "dont_paint", "n"),
-        fpdf.drawing.PathPaintRule.DONT_PAINT,
+        PathPaintRule,
+        (PathPaintRule.DONT_PAINT, "dont_paint", "n"),
+        PathPaintRule.DONT_PAINT,
         no_exception,
         id="PathPaintRule.DONT_PAINT",
     ),
     pytest.param(
-        fpdf.drawing.PathPaintRule,
-        (fpdf.drawing.PathPaintRule.AUTO, "auto"),
-        fpdf.drawing.PathPaintRule.AUTO,
+        PathPaintRule,
+        (PathPaintRule.AUTO, "auto"),
+        PathPaintRule.AUTO,
         no_exception,
         id="PathPaintRule.AUTO",
     ),
     pytest.param(
-        fpdf.drawing.ClippingPathIntersectionRule,
-        (fpdf.drawing.ClippingPathIntersectionRule.NONZERO, "nonzero", "W"),
-        fpdf.drawing.ClippingPathIntersectionRule.NONZERO,
+        ClippingPathIntersectionRule,
+        (ClippingPathIntersectionRule.NONZERO, "nonzero", "W"),
+        ClippingPathIntersectionRule.NONZERO,
         no_exception,
         id="ClippingPathIntersectionRule.NONZERO",
     ),
     pytest.param(
-        fpdf.drawing.ClippingPathIntersectionRule,
-        (fpdf.drawing.ClippingPathIntersectionRule.EVENODD, "evenodd", "W*"),
-        fpdf.drawing.ClippingPathIntersectionRule.EVENODD,
+        ClippingPathIntersectionRule,
+        (ClippingPathIntersectionRule.EVENODD, "evenodd", "W*"),
+        ClippingPathIntersectionRule.EVENODD,
         no_exception,
         id="ClippingPathIntersectionRule.EVENODD",
     ),
     pytest.param(
-        fpdf.drawing.StrokeCapStyle,
+        StrokeCapStyle,
         (-1,),
         None,
         exception(ValueError),
         id="int coerce out of range",
     ),
     pytest.param(
-        fpdf.drawing.StrokeCapStyle,
+        StrokeCapStyle,
         ("nonsense",),
         None,
         exception(ValueError),
         id="int coerce bad key",
     ),
     pytest.param(
-        fpdf.drawing.StrokeCapStyle,
+        StrokeCapStyle,
         (1.0, object()),
         None,
         exception(TypeError),
         id="int coerce bad type",
     ),
     pytest.param(
-        fpdf.drawing.StrokeCapStyle,
-        (fpdf.drawing.StrokeCapStyle.BUTT, "butt", 0),
-        fpdf.drawing.StrokeCapStyle.BUTT,
+        StrokeCapStyle,
+        (StrokeCapStyle.BUTT, "butt", 0),
+        StrokeCapStyle.BUTT,
         no_exception,
         id="StrokeCapStyle.BUTT",
     ),
     pytest.param(
-        fpdf.drawing.StrokeCapStyle,
-        (fpdf.drawing.StrokeCapStyle.ROUND, "round", 1),
-        fpdf.drawing.StrokeCapStyle.ROUND,
+        StrokeCapStyle,
+        (StrokeCapStyle.ROUND, "round", 1),
+        StrokeCapStyle.ROUND,
         no_exception,
         id="StrokeCapStyle.ROUND",
     ),
     pytest.param(
-        fpdf.drawing.StrokeCapStyle,
-        (fpdf.drawing.StrokeCapStyle.SQUARE, "square", 2),
-        fpdf.drawing.StrokeCapStyle.SQUARE,
+        StrokeCapStyle,
+        (StrokeCapStyle.SQUARE, "square", 2),
+        StrokeCapStyle.SQUARE,
         no_exception,
         id="StrokeCapStyle.SQUARE",
     ),
     pytest.param(
-        fpdf.drawing.StrokeJoinStyle,
-        (fpdf.drawing.StrokeJoinStyle.MITER, "miter", 0),
-        fpdf.drawing.StrokeJoinStyle.MITER,
+        StrokeJoinStyle,
+        (StrokeJoinStyle.MITER, "miter", 0),
+        StrokeJoinStyle.MITER,
         no_exception,
         id="StrokeJoinStyle.MITER",
     ),
     pytest.param(
-        fpdf.drawing.StrokeJoinStyle,
-        (fpdf.drawing.StrokeJoinStyle.ROUND, "round", 1),
-        fpdf.drawing.StrokeJoinStyle.ROUND,
+        StrokeJoinStyle,
+        (StrokeJoinStyle.ROUND, "round", 1),
+        StrokeJoinStyle.ROUND,
         no_exception,
         id="StrokeJoinStyle.ROUND",
     ),
     pytest.param(
-        fpdf.drawing.StrokeJoinStyle,
-        (fpdf.drawing.StrokeJoinStyle.BEVEL, "bevel", 2),
-        fpdf.drawing.StrokeJoinStyle.BEVEL,
+        StrokeJoinStyle,
+        (StrokeJoinStyle.BEVEL, "bevel", 2),
+        StrokeJoinStyle.BEVEL,
         no_exception,
         id="StrokeJoinStyle.BEVEL",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.NORMAL, "normal"),
-        fpdf.drawing.BlendMode.NORMAL,
+        BlendMode,
+        (BlendMode.NORMAL, "normal"),
+        BlendMode.NORMAL,
         no_exception,
         id="BlendMode.NORMAL",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.MULTIPLY, "multiply"),
-        fpdf.drawing.BlendMode.MULTIPLY,
+        BlendMode,
+        (BlendMode.MULTIPLY, "multiply"),
+        BlendMode.MULTIPLY,
         no_exception,
         id="BlendMode.MULTIPLY",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.SCREEN, "screen"),
-        fpdf.drawing.BlendMode.SCREEN,
+        BlendMode,
+        (BlendMode.SCREEN, "screen"),
+        BlendMode.SCREEN,
         no_exception,
         id="BlendMode.SCREEN",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.OVERLAY, "overlay"),
-        fpdf.drawing.BlendMode.OVERLAY,
+        BlendMode,
+        (BlendMode.OVERLAY, "overlay"),
+        BlendMode.OVERLAY,
         no_exception,
         id="BlendMode.OVERLAY",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.DARKEN, "darken"),
-        fpdf.drawing.BlendMode.DARKEN,
+        BlendMode,
+        (BlendMode.DARKEN, "darken"),
+        BlendMode.DARKEN,
         no_exception,
         id="BlendMode.DARKEN",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.LIGHTEN, "lighten"),
-        fpdf.drawing.BlendMode.LIGHTEN,
+        BlendMode,
+        (BlendMode.LIGHTEN, "lighten"),
+        BlendMode.LIGHTEN,
         no_exception,
         id="BlendMode.LIGHTEN",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.COLOR_DODGE, "color_dodge"),
-        fpdf.drawing.BlendMode.COLOR_DODGE,
+        BlendMode,
+        (BlendMode.COLOR_DODGE, "color_dodge"),
+        BlendMode.COLOR_DODGE,
         no_exception,
         id="BlendMode.COLOR_DODGE",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.COLOR_BURN, "color_burn"),
-        fpdf.drawing.BlendMode.COLOR_BURN,
+        BlendMode,
+        (BlendMode.COLOR_BURN, "color_burn"),
+        BlendMode.COLOR_BURN,
         no_exception,
         id="BlendMode.COLOR_BURN",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.HARD_LIGHT, "hard_light"),
-        fpdf.drawing.BlendMode.HARD_LIGHT,
+        BlendMode,
+        (BlendMode.HARD_LIGHT, "hard_light"),
+        BlendMode.HARD_LIGHT,
         no_exception,
         id="BlendMode.HARD_LIGHT",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.SOFT_LIGHT, "soft_light"),
-        fpdf.drawing.BlendMode.SOFT_LIGHT,
+        BlendMode,
+        (BlendMode.SOFT_LIGHT, "soft_light"),
+        BlendMode.SOFT_LIGHT,
         no_exception,
         id="BlendMode.SOFT_LIGHT",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.DIFFERENCE, "difference"),
-        fpdf.drawing.BlendMode.DIFFERENCE,
+        BlendMode,
+        (BlendMode.DIFFERENCE, "difference"),
+        BlendMode.DIFFERENCE,
         no_exception,
         id="BlendMode.DIFFERENCE",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.EXCLUSION, "exclusion"),
-        fpdf.drawing.BlendMode.EXCLUSION,
+        BlendMode,
+        (BlendMode.EXCLUSION, "exclusion"),
+        BlendMode.EXCLUSION,
         no_exception,
         id="BlendMode.EXCLUSION",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.HUE, "hue"),
-        fpdf.drawing.BlendMode.HUE,
+        BlendMode,
+        (BlendMode.HUE, "hue"),
+        BlendMode.HUE,
         no_exception,
         id="BlendMode.HUE",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.SATURATION, "saturation"),
-        fpdf.drawing.BlendMode.SATURATION,
+        BlendMode,
+        (BlendMode.SATURATION, "saturation"),
+        BlendMode.SATURATION,
         no_exception,
         id="BlendMode.SATURATION",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.COLOR, "color"),
-        fpdf.drawing.BlendMode.COLOR,
+        BlendMode,
+        (BlendMode.COLOR, "color"),
+        BlendMode.COLOR,
         no_exception,
         id="BlendMode.COLOR",
     ),
     pytest.param(
-        fpdf.drawing.BlendMode,
-        (fpdf.drawing.BlendMode.LUMINOSITY, "luminosity"),
-        fpdf.drawing.BlendMode.LUMINOSITY,
+        BlendMode,
+        (BlendMode.LUMINOSITY, "luminosity"),
+        BlendMode.LUMINOSITY,
         no_exception,
         id="BlendMode.LUMINOSITY",
     ),
@@ -460,7 +473,12 @@ invalid_styles = (
     ),
     pytest.param("fill_color", "123", ValueError, id="invalid string fill_color"),
     pytest.param("fill_color", 2, TypeError, id="invalid numeric fill_color"),
-    pytest.param("fill_opacity", "123123", TypeError, id="invalid string fill_opacity"),
+    pytest.param(
+        "fill_opacity",
+        "123123",
+        (TypeError, AssertionError),
+        id="invalid string fill_opacity",
+    ),
     pytest.param("fill_opacity", 2, ValueError, id="invalid numeric fill_opacity"),
     pytest.param("stroke_color", [2], TypeError, id="invalid stroke_color"),
     pytest.param(
@@ -483,198 +501,193 @@ invalid_styles = (
 )
 
 
-M = fpdf.drawing.Move
-L = fpdf.drawing.Line
-B = fpdf.drawing.BezierCurve
+M = Move
+L = Line
+B = BezierCurve
 
 path_elements = (
     pytest.param(
         P(1, 1),
-        fpdf.drawing.Move(P(1, 2)),
+        Move(P(1, 2)),
         "1 2 m",
         P(1, 2),
-        fpdf.drawing.Move,
+        Move,
         id="move",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.RelativeMove(P(1, 2)),
+        RelativeMove(P(1, 2)),
         "2 3 m",
         P(2, 3),
-        fpdf.drawing.Move,
+        Move,
         id="relative move",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.Line(P(1, 2)),
+        Line(P(1, 2)),
         "1 2 l",
         P(1, 2),
-        fpdf.drawing.Line,
+        Line,
         id="line",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.RelativeLine(P(1, 2)),
+        RelativeLine(P(1, 2)),
         "2 3 l",
         P(2, 3),
-        fpdf.drawing.Line,
+        Line,
         id="relative line",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.HorizontalLine(2),
+        HorizontalLine(2),
         "2 1 l",
         P(2, 1),
-        fpdf.drawing.Line,
+        Line,
         id="horizontal line",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.RelativeHorizontalLine(2),
+        RelativeHorizontalLine(2),
         "3 1 l",
         P(3, 1),
-        fpdf.drawing.Line,
+        Line,
         id="relative horizontal line",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.VerticalLine(2),
+        VerticalLine(2),
         "1 2 l",
         P(1, 2),
-        fpdf.drawing.Line,
+        Line,
         id="vertical line",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.RelativeVerticalLine(2),
+        RelativeVerticalLine(2),
         "1 3 l",
         P(1, 3),
-        fpdf.drawing.Line,
+        Line,
         id="relative vertical line",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.BezierCurve(P(1, 2), P(3, 4), P(5, 6)),
+        BezierCurve(P(1, 2), P(3, 4), P(5, 6)),
         "1 2 3 4 5 6 c",
         P(5, 6),
-        fpdf.drawing.BezierCurve,
+        BezierCurve,
         id="cubic bezier curve",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.RelativeBezierCurve(P(1, 2), P(3, 4), P(5, 6)),
+        RelativeBezierCurve(P(1, 2), P(3, 4), P(5, 6)),
         "2 3 4 5 6 7 c",
         P(6, 7),
-        fpdf.drawing.BezierCurve,
+        BezierCurve,
         id="relative cubic bezier curve",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.QuadraticBezierCurve(P(1, 2), P(3, 4)),
+        QuadraticBezierCurve(P(1, 2), P(3, 4)),
         "1 1.6667 1.6667 2.6667 3 4 c",
         P(3, 4),
-        fpdf.drawing.QuadraticBezierCurve,
+        QuadraticBezierCurve,
         id="quadratic bezier curve",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.RelativeQuadraticBezierCurve(P(1, 2), P(3, 4)),
+        RelativeQuadraticBezierCurve(P(1, 2), P(3, 4)),
         "1.6667 2.3333 2.6667 3.6667 4 5 c",
         P(4, 5),
-        fpdf.drawing.QuadraticBezierCurve,
+        QuadraticBezierCurve,
         id="relative quadratic bezier curve",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.Arc(P(1, 2), 0, True, True, P(3, 4)),
+        Arc(P(1, 2), 0, True, True, P(3, 4)),
         "1.4142 -0.1046 2.1977 -0.3284 2.75 0.5 c 3.3023 1.3284 3.4142 2.8954 3 4 c",
         P(3, 4),
-        fpdf.drawing.BezierCurve,
+        BezierCurve,
         id="arc",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.RelativeArc(P(1, 2), 0, True, True, P(3, 4)),
+        RelativeArc(P(1, 2), 0, True, True, P(3, 4)),
         "1.5523 -0.6569 2.6716 -1.1046 3.5 0 c 4.3284 1.1046 4.5523 3.3431 4 5 c",
         P(4, 5),
-        fpdf.drawing.BezierCurve,
+        BezierCurve,
         id="relative arc",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.Rectangle(P(1, 2), P(3, 4)),
+        Rectangle(P(1, 2), P(3, 4)),
         "1 2 3 4 re",
         P(1, 2),
-        fpdf.drawing.Line,
+        Line,
         id="rectangle",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.RoundedRectangle(P(1, 2), P(6, 6), P(1, 2)),
+        RoundedRectangle(P(1, 2), P(6, 6), P(1, 2)),
         (
             "2 2 m 6 2 l 6.5523 2 7 2.8954 7 4 c 7 6 l 7 7.1046 6.5523 8 6 8 c 2 8 l "
             "1.4477 8 1 7.1046 1 6 c 1 4 l 1 2.8954 1.4477 2 2 2 c h"
         ),
         P(1, 2),
-        fpdf.drawing.Line,
+        Line,
         id="rounded rectangle",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.Ellipse(P(1, 2), P(3, 4)),
+        Ellipse(P(1, 2), P(3, 4)),
         (
             "4 4 m 4 5.1046 3.5523 6 3 6 c 2.4477 6 2 5.1046 2 4 c 2 2.8954 2.4477 2 3 2 c "
             "3.5523 2 4 2.8954 4 4 c h"
         ),
         P(3, 4),
-        fpdf.drawing.Move,
+        Move,
         id="rounded rectangle",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.Ellipse(P(1, 2), P(3, 4)),
+        Ellipse(P(1, 2), P(3, 4)),
         (
             "4 4 m 4 5.1046 3.5523 6 3 6 c 2.4477 6 2 5.1046 2 4 c 2 2.8954 2.4477 2 3 2 c "
             "3.5523 2 4 2.8954 4 4 c h"
         ),
         P(3, 4),
-        fpdf.drawing.Move,
+        Move,
         id="ellipse",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.ImplicitClose(),
+        ImplicitClose(),
         "",
         P(1, 1),
-        fpdf.drawing.Move,
+        Move,
         id="implicit close",
     ),
     pytest.param(
         P(1, 1),
-        fpdf.drawing.Close(),
+        Close(),
         "h",
         P(1, 1),
-        fpdf.drawing.Move,
+        Move,
         id="close",
     ),
 )
 
-PP = fpdf.drawing.PaintedPath
-d = fpdf.drawing
+PP = PaintedPath
 
 paint_rules = (
-    pytest.param(
-        fpdf.drawing.PathPaintRule.STROKE, fpdf.drawing.PathPaintRule.STROKE, id="Enum"
-    ),
-    pytest.param(
-        "FILL_EVENODD", fpdf.drawing.PathPaintRule.FILL_EVENODD, id="matching string"
-    ),
+    pytest.param(PathPaintRule.STROKE, PathPaintRule.STROKE, id="Enum"),
+    pytest.param("FILL_EVENODD", PathPaintRule.FILL_EVENODD, id="matching string"),
     pytest.param(
         "stroke_fill_nonzero",
-        fpdf.drawing.PathPaintRule.STROKE_FILL_NONZERO,
+        PathPaintRule.STROKE_FILL_NONZERO,
         id="matching string after uppercasing",
     ),
-    pytest.param(None, fpdf.drawing.PathPaintRule.DONT_PAINT, id="None"),
+    pytest.param(None, PathPaintRule.DONT_PAINT, id="None"),
 )
 
 clipping_path_result = (
@@ -691,13 +704,13 @@ painted_path_elements = (
     # circle, ellipse, rectangle
     pytest.param(
         ((PP.rectangle, (1, 2, 3, 4)),),
-        [d.Move(P(0, 0)), d.RoundedRectangle(P(1, 2), P(3, 4), P(0, 0))],
+        [Move(P(0, 0)), RoundedRectangle(P(1, 2), P(3, 4), P(0, 0))],
         ("q 0 0 m 1 2 3 4 re B Q", "0 0 m 1 2 3 4 re W n"),
         id="rectangle",
     ),
     pytest.param(
         ((PP.circle, (1, 2, 3)),),
-        [d.Move(P(0, 0)), d.Ellipse(center=P(1, 2), radii=P(3, 3))],
+        [Move(P(0, 0)), Ellipse(center=P(1, 2), radii=P(3, 3))],
         (
             (
                 "q 0 0 m 4 2 m 4 3.6569 2.6569 5 1 5 c -0.6569 5 -2 3.6569 -2 2 c -2 0.3431 "
@@ -712,7 +725,7 @@ painted_path_elements = (
     ),
     pytest.param(
         ((PP.ellipse, (1, 2, 3, 4)),),
-        [d.Move(P(0, 0)), d.Ellipse(center=P(1, 2), radii=P(3, 4))],
+        [Move(P(0, 0)), Ellipse(center=P(1, 2), radii=P(3, 4))],
         (
             (
                 "q 0 0 m 4 2 m 4 4.2091 2.6569 6 1 6 c -0.6569 6 -2 4.2091 -2 2 c -2 -0.2091 "
@@ -727,55 +740,55 @@ painted_path_elements = (
     ),
     pytest.param(
         ((PP.line_to, (2, 1)),),
-        [d.Move(P(0, 0)), d.Line(P(2, 1))],
+        [Move(P(0, 0)), Line(P(2, 1))],
         ("q 0 0 m 2 1 l h B Q", "0 0 m 2 1 l W n"),
         id="line_to",
     ),
     pytest.param(
         ((PP.line_relative, (2, 1)),),
-        [d.Move(P(0, 0)), d.RelativeLine(P(2, 1))],
+        [Move(P(0, 0)), RelativeLine(P(2, 1))],
         ("q 0 0 m 2 1 l h B Q", "0 0 m 2 1 l W n"),
         id="line_relative",
     ),
     pytest.param(
         ((PP.horizontal_line_to, (2,)),),
-        [d.Move(P(0, 0)), d.HorizontalLine(2)],
+        [Move(P(0, 0)), HorizontalLine(2)],
         ("q 0 0 m 2 0 l h B Q", "0 0 m 2 0 l W n"),
         id="horizontal_line_to",
     ),
     pytest.param(
         ((PP.horizontal_line_relative, (2,)),),
-        [d.Move(P(0, 0)), d.RelativeHorizontalLine(2)],
+        [Move(P(0, 0)), RelativeHorizontalLine(2)],
         ("q 0 0 m 2 0 l h B Q", "0 0 m 2 0 l W n"),
         id="horizontal_line_relative",
     ),
     pytest.param(
         ((PP.vertical_line_to, (2,)),),
-        [d.Move(P(0, 0)), d.VerticalLine(2)],
+        [Move(P(0, 0)), VerticalLine(2)],
         ("q 0 0 m 0 2 l h B Q", "0 0 m 0 2 l W n"),
         id="vertical_line_to",
     ),
     pytest.param(
         ((PP.vertical_line_relative, (2,)),),
-        [d.Move(P(0, 0)), d.RelativeVerticalLine(2)],
+        [Move(P(0, 0)), RelativeVerticalLine(2)],
         ("q 0 0 m 0 2 l h B Q", "0 0 m 0 2 l W n"),
         id="vertical_line_relative",
     ),
     pytest.param(
         ((PP.curve_to, (1, 2, 3, 4, 5, 6)),),
-        [d.Move(P(0, 0)), d.BezierCurve(P(1, 2), P(3, 4), P(5, 6))],
+        [Move(P(0, 0)), BezierCurve(P(1, 2), P(3, 4), P(5, 6))],
         ("q 0 0 m 1 2 3 4 5 6 c h B Q", "0 0 m 1 2 3 4 5 6 c W n"),
         id="curve_to",
     ),
     pytest.param(
         ((PP.curve_relative, (1, 2, 3, 4, 5, 6)),),
-        [d.Move(P(0, 0)), d.RelativeBezierCurve(P(1, 2), P(3, 4), P(5, 6))],
+        [Move(P(0, 0)), RelativeBezierCurve(P(1, 2), P(3, 4), P(5, 6))],
         ("q 0 0 m 1 2 3 4 5 6 c h B Q", "0 0 m 1 2 3 4 5 6 c W n"),
         id="curve_relative",
     ),
     pytest.param(
         ((PP.quadratic_curve_to, (1, 2, 3, 4)),),
-        [d.Move(P(0, 0)), d.QuadraticBezierCurve(P(1, 2), P(3, 4))],
+        [Move(P(0, 0)), QuadraticBezierCurve(P(1, 2), P(3, 4))],
         (
             "q 0 0 m 0.6667 1.3333 1.6667 2.6667 3 4 c h B Q",
             "0 0 m 0.6667 1.3333 1.6667 2.6667 3 4 c W n",
@@ -784,7 +797,7 @@ painted_path_elements = (
     ),
     pytest.param(
         ((PP.quadratic_curve_relative, (1, 2, 3, 4)),),
-        [d.Move(P(0, 0)), d.RelativeQuadraticBezierCurve(P(1, 2), P(3, 4))],
+        [Move(P(0, 0)), RelativeQuadraticBezierCurve(P(1, 2), P(3, 4))],
         (
             "q 0 0 m 0.6667 1.3333 1.6667 2.6667 3 4 c h B Q",
             "0 0 m 0.6667 1.3333 1.6667 2.6667 3 4 c W n",
@@ -793,7 +806,7 @@ painted_path_elements = (
     ),
     pytest.param(
         ((PP.arc_to, (3, 3, 0, False, False, 1, 1)),),
-        [d.Move(P(0, 0)), d.Arc(P(3, 3), 0, False, False, P(1, 1))],
+        [Move(P(0, 0)), Arc(P(3, 3), 0, False, False, P(1, 1))],
         (
             "q 0 0 m 0.2489 0.4083 0.5917 0.7511 1 1 c h B Q",
             "0 0 m 0.2489 0.4083 0.5917 0.7511 1 1 c W n",
@@ -802,7 +815,7 @@ painted_path_elements = (
     ),
     pytest.param(
         ((PP.arc_relative, (3, 3, 0, False, False, 1, 1)),),
-        [d.Move(P(0, 0)), d.RelativeArc(P(3, 3), 0, False, False, P(1, 1))],
+        [Move(P(0, 0)), RelativeArc(P(3, 3), 0, False, False, P(1, 1))],
         (
             "q 0 0 m 0.2489 0.4083 0.5917 0.7511 1 1 c h B Q",
             "0 0 m 0.2489 0.4083 0.5917 0.7511 1 1 c W n",
@@ -811,7 +824,7 @@ painted_path_elements = (
     ),
     pytest.param(
         ((PP.close, ()),),
-        [d.Move(P(0, 0)), d.Close()],
+        [Move(P(0, 0)), Close()],
         ("q 0 0 m h B Q", "0 0 m h W n"),
         id="close",
     ),
