@@ -1,5 +1,4 @@
 # pylint: disable=no-self-use, protected-access
-import io
 from pathlib import Path
 
 import fpdf
@@ -11,7 +10,8 @@ import pytest
 
 from . import parameters
 
-GENERATED_PDF_DIR = Path(__file__).resolve().parent / "generated_pdf"
+HERE = Path(__file__).resolve().parent
+GENERATED_PDF_DIR = HERE / "generated_pdf"
 
 
 def assert_style_match(lhs, rhs):
@@ -109,25 +109,18 @@ class TestSVGPathParsing:
         with pytest.raises(ValueError):
             fpdf.svg.svg_path_converter(pdf_path, "A 1 2 0 1 0 4 5")
 
-    @pytest.mark.parametrize(
-        "debug", (pytest.param(False, id="no debug"), pytest.param(True, id="debug"))
-    )
     @pytest.mark.parametrize("path, expected", parameters.svg_path_render_tests)
-    def test_rendering_smooth_curves(self, debug, path, expected):
+    def test_rendering_smooth_curves(self, path, expected):
         pdf_path = fpdf.drawing.PaintedPath()
 
         fpdf.svg.svg_path_converter(pdf_path, path)
 
-        gsdr = fpdf.drawing.GraphicsStateDictRegistry()
+        resource_catalog = fpdf.output.ResourceCatalog()
         style = fpdf.drawing.GraphicsStyle()
         first_point = fpdf.drawing.Point(0, 0)
         start = fpdf.drawing.Move(first_point)
 
-        if debug:
-            dbg = io.StringIO()
-            result = pdf_path.render_debug(gsdr, style, start, first_point, dbg, "")[0]
-        else:
-            result = pdf_path.render(gsdr, style, start, first_point)[0]
+        result = pdf_path.render(resource_catalog, style, start, first_point)[0]
 
         assert result == expected
 
@@ -280,6 +273,29 @@ class TestSVGObject:
 
         assert_pdf_equal(pdf, GENERATED_PDF_DIR / f"{svg_file.stem}.pdf", tmp_path)
 
+    @pytest.mark.parametrize(
+        "fill_color, stroke_color, file_suffix", parameters.svg_current_color
+    )
+    def test_svg_current_color(self, tmp_path, fill_color, stroke_color, file_suffix):
+        svg_file = parameters.svgfile("simple_rect_current_color.svg")
+
+        svg = fpdf.svg.SVGObject.from_file(svg_file)
+
+        pdf = fpdf.FPDF(unit="pt", format=(svg.width, svg.height))
+        pdf.set_margin(0)
+        pdf.allow_images_transparency = False
+        pdf.add_page()
+
+        if fill_color is not None:
+            pdf.set_fill_color(fill_color[0], fill_color[1], fill_color[2])
+        if stroke_color is not None:
+            pdf.set_draw_color(stroke_color[0], stroke_color[1], stroke_color[2])
+        svg.draw_to_page(pdf)
+
+        assert_pdf_equal(
+            pdf, GENERATED_PDF_DIR / f"{svg_file.stem}{file_suffix}.pdf", tmp_path
+        )
+
     def test_svg_render_content_in_a_tag(self, tmp_path):
         svg_file = parameters.svgfile("simple_rect_in_a_tag.svg")
 
@@ -303,3 +319,23 @@ class TestSVGObject:
         assert_pdf_equal(
             pdf, GENERATED_PDF_DIR / "svg_rendering_image_over_page_break.pdf", tmp_path
         )
+
+    def test_svg_text_ttf_font(self, tmp_path):
+        pdf = fpdf.FPDF()
+        pdf.add_page()
+        pdf.add_font(
+            family="serif", style="", fname=HERE.parent / "fonts" / "DejaVuSans.ttf"
+        )
+        pdf.image(
+            name=HERE / "svg_sources" / "ocanada.svg",
+            x=pdf.l_margin,
+            y=pdf.t_margin,
+            w=pdf.epw,
+            h=pdf.eph,
+            keep_aspect_ratio=True,
+        )
+        assert_pdf_equal(
+            pdf,
+            GENERATED_PDF_DIR / "ocanada.pdf",
+            tmp_path,
+        )
