@@ -86,6 +86,25 @@ def test_goto_action(tmp_path):
     assert_pdf_equal(pdf, HERE / "goto_action.pdf", tmp_path)
 
 
+def test_goto_action_named_destination(tmp_path):
+    pdf = FPDF()
+    pdf.set_font("Helvetica", size=24)
+    pdf.add_page()
+    x, y, text = 80, 140, "GoTo action"
+    pdf.text(x=x, y=y, text=text)
+    pdf.add_action(
+        GoToAction(dest="#page2"),
+        x=x,
+        y=y - pdf.font_size,
+        w=pdf.get_string_width(text),
+        h=pdf.font_size,
+    )
+    pdf.add_page()
+    pdf.add_link(y=140, name="page2")
+    pdf.text(x=80, y=140, text="Page 2")
+    assert_pdf_equal(pdf, HERE / "goto_action_named_destination.pdf", tmp_path)
+
+
 def test_goto_remote_action(tmp_path):
     pdf = FPDF()
     pdf.set_font("Helvetica", size=24)
