@@ -1,6 +1,13 @@
 from fpdf import FPDF, FPDFException, TextMode
-from fpdf.line_break import Fragment, MultiLineBreak, CurrentLine, TextLine
+from fpdf.line_break import (
+    Fragment,
+    MultiLineBreak,
+    CurrentLine,
+    TextLine,
+    TotalPagesSubstitutionFragment,
+)
 from fpdf.enums import Align, CharVPos
+from fpdf.graphics_state import GraphicsState
 
 import pytest
 
@@ -21,6 +28,10 @@ class FxFragment(Fragment):
         return cw[character]
 
 
+class FxTotalPagesSubstitutionFragment(FxFragment, TotalPagesSubstitutionFragment):
+    pass
+
+
 class FxFont:
     def __init__(self, cw):
         self.i = 1
@@ -134,23 +145,23 @@ def test_no_fragments():
     assert multi_line_break.get_line() is None
 
 
-_gs_normal = dict(
+_gs_normal = GraphicsState(
     font_style="normal",
     font_size_pt=12,
     font_family="helvetica",
     font_stretching=100,
     char_spacing=0,
-    current_font={},
+    current_font=None,
     char_vpos=CharVPos.LINE,
     text_shaping=None,
 )
-_gs_bold = dict(
+_gs_bold = GraphicsState(
     font_style="bold",
     font_size_pt=12,
     font_family="helvetica",
     font_stretching=100,
     char_spacing=0,
-    current_font={},
+    current_font=None,
     char_vpos=CharVPos.LINE,
     text_shaping=None,
 )
@@ -158,7 +169,7 @@ _gs_bold = dict(
 
 def gs_with_font(graphics_state, cw):
     gs = graphics_state
-    gs["current_font"] = FxFont(cw)
+    gs.current_font = FxFont(cw)
     return gs
 
 
@@ -179,7 +190,7 @@ def test_width_calculation():
         alphabet["normal"][char] = char_width + i
     alphabet["normal"][" "] = char_width
     gs = _gs_normal
-    gs["current_font"] = FxFont(alphabet["normal"])
+    gs.current_font = FxFont(alphabet["normal"])
     fragments = [FxFragment(text, gs, 1, None, alphabet)]
     multi_line_break = MultiLineBreak(fragments, _get_width, [0, 0])
 
@@ -238,7 +249,7 @@ def test_single_space_in_fragment():
         "normal": {},
     }
     gs = _gs_normal
-    gs["current_font"] = FxFont(alphabet["normal"])
+    gs.current_font = FxFont(alphabet["normal"])
     fragments = [FxFragment(text, gs, 1, None, alphabet)]
     for char in text:
         alphabet["normal"][char] = char_width
@@ -1428,3 +1439,47 @@ def test_line_break_no_initial_newline():  # issue-847
     multi_line_break = MultiLineBreak(fragments, 188, [0, 0])
     text_line = multi_line_break.get_line()
     assert text_line.fragments
+
+
+def test_substitution_fragments_are_not_merged_with_base_fragments():
+    """
+    There are three fragments, all of which fit on a single line. Normally, they would be merged into one fragment.
+    However, a substitution fragment cannot be merged with a base fragment, otherwise,
+    characters from the base fragment would be lost after replacement.
+
+    Expected behavior:
+        The fragments are not merged.
+    """
+    pdf = FPDF()
+    assert pdf.str_alias_nb_pages
+    alias = pdf.str_alias_nb_pages
+
+    char_width = 6
+    line_width = 200 * char_width
+    text_before = "before"
+    text_after = "after"
+
+    alphabet = {
+        "normal": {},
+    }
+    for char in text_before + alias + text_after:
+        alphabet["normal"][char] = char_width
+
+    graphics_state = gs_with_font(_gs_normal, alphabet["normal"])
+
+    fragment_before = FxFragment(text_before, graphics_state, 1, None, alphabet)
+    fragment_after = FxFragment(text_after, graphics_state, 1, None, alphabet)
+    substitution_fragment = FxTotalPagesSubstitutionFragment(
+        alias, graphics_state, 1, None, alphabet
+    )
+
+    multi_line_break = MultiLineBreak(
+        [fragment_before, substitution_fragment, fragment_after],
+        line_width,
+        [0, 0],
+    )
+
+    line = multi_line_break.get_line()
+    assert line.fragments == [fragment_before, substitution_fragment, fragment_after]
+
+    assert multi_line_break.get_line() is None
