@@ -5,8 +5,7 @@ md = (
     .enable("strikethrough")
     .enable("table")
 )
-html = md.render(
-    """
+html = md.render("""
 # Top title (ATX)
 
 Subtitle (setext)
@@ -57,8 +56,7 @@ Some horizontal thematic breaks:
 ___
 
 ![Alternate description](https://py-pdf.github.io/fpdf2/fpdf2-logo.png)
-"""
-)
+""")
 
 from fpdf import FPDF
 
