@@ -4,7 +4,7 @@
 # USAGE: ./ods2table.py color_srgb.ods
 import sys
 from fpdf import FPDF, FontFace
-from fpdf.drawing import color_from_hex_string
+from fpdf.drawing_primitives import color_from_hex_string
 from odf.opendocument import load
 from odf.table import Table, TableCell, TableRow
 
